@@ -56,36 +56,15 @@ class AccessRight(object):
         result: str = '['
         prefix: str = ''
         if self.read:
-            result += TenantAccessRight.READ
+            result += AccessRight.READ
             prefix = ", "
         if self.write:
-            result += prefix + TenantAccessRight.WRITE
+            result += prefix + AccessRight.WRITE
         if self.delete:
-            result += TenantAccessRight.DELETE
+            result += AccessRight.DELETE
         result += ']'
         return result
 
-    @classmethod
-    def parse(cls, param: List[str]) -> 'TenantAccessRight':
-        """
-        Converts the access to list of properties.
-
-        Parameters
-        ----------
-        param: List[str]
-            List of rights
-
-        Returns
-        -------
-        tenant_rights: TenantAccessRight
-            Instantiated rights.
-        """
-        rights: TenantAccessRight = TenantAccessRight()
-        rights.read = TenantAccessRight.READ in param
-        rights.write = TenantAccessRight.WRITE in param
-        rights.delete = TenantAccessRight.DELETE in param
-        return rights
-
     def to_list(self) -> List[str]:
         """
         Converts the access to list of properties.
@@ -124,6 +103,27 @@ class TenantAccessRight(AccessRight):
     def __init__(self, read: bool = False, write: bool = False, delete: bool = False):
         super().__init__(read, write, delete)
 
+    @classmethod
+    def parse(cls, param: List[str]) -> 'TenantAccessRight':
+        """
+        Converts the access to list of properties.
+
+        Parameters
+        ----------
+        param: List[str]
+            List of rights
+
+        Returns
+        -------
+        tenant_rights: TenantAccessRight
+            Instantiated rights.
+        """
+        rights: TenantAccessRight = TenantAccessRight()
+        rights.read = TenantAccessRight.READ in param
+        rights.write = TenantAccessRight.WRITE in param
+        rights.delete = TenantAccessRight.DELETE in param
+        return rights
+
 
 class GroupAccessRight(AccessRight):
     """
@@ -134,12 +134,33 @@ class GroupAccessRight(AccessRight):
     Parameters
     ----------
     read: bool (default := False)
-        Read access for entity within tenant.
+        Read access for entity within group.
     write: bool (default := False)
-        Write access for entity within tenant.
+        Write access for entity within group.
     delete: bool (default := False)
-        Delete access for entity within tenant.
+        Delete access for entity within group.
     """
 
     def __init__(self, read: bool = False, write: bool = False, delete: bool = False):
         super().__init__(read, write, delete)
+
+    @classmethod
+    def parse(cls, param: List[str]) -> 'GroupAccessRight':
+        """
+        Converts the access to list of properties.
+
+        Parameters
+        ----------
+        param: List[str]
+            List of rights
+
+        Returns
+        -------
+        group_rights: GroupAccessRight
+            Instantiated rights.
+        """
+        rights: GroupAccessRight = GroupAccessRight()
+        rights.read = GroupAccessRight.READ in param
+        rights.write = GroupAccessRight.WRITE in param
+        rights.delete = GroupAccessRight.DELETE in param
+        return rights
