@@ -25,7 +25,7 @@ class WacomEntityLinkingEngine(PersonalEntityLinkingProcessor):
         URL of the service
     """
     SERVICE_ENDPOINT: str = 'graph/nel/text'
-    SERVICE_URL: str = 'https://stage-private-knowledge.wacom.com'
+    SERVICE_URL: str = 'https://private-knowledge.wacom.com'
     LANGUAGES: List[LanguageCode] = [
         LanguageCode('de_DE'),
         LanguageCode('en_US'),
